@@ -269,7 +269,7 @@ class FileStorageClient(object):
     
     
     def exists(self, id):
-        dirpath = os.path.join(self._id_to_dirpath(id), u'MANIFEST')
+        dirpath = os.path.join(self._id_to_dirpath(id))
         return os.path.exists(dirpath)
     
     def _get_new_id(self):
